==> pymanopt-1.0.0.tar.gz: pymanopt-1.0.0/tests/optimizers/test_optimizers.py <==
import autograd.numpy as np
from nose2.tools import params

import pymanopt
import pymanopt.optimizers
from pymanopt.manifolds import Sphere

from .._test import TestCase


class TestOptimizers(TestCase):
    def setUp(self):
        n = 32
        matrix = np.random.normal(size=(n, n))
        self.manifold = manifold = Sphere(n)
        self.max_iterations = 50

        @pymanopt.function.autograd(manifold)
        def cost(point):
            return -point.T @ matrix @ point

        self.problem = pymanopt.Problem(manifold, cost)

    @params(*pymanopt.optimizers.OPTIMIZERS)
    def test_optimizers(self, optimizer_name):
        optimizer = getattr(pymanopt.optimizers, optimizer_name)(
            max_iterations=self.max_iterations, verbosity=0
        )
        result = optimizer.run(self.problem)
        assert result.point.shape == self.manifold.random_point().shape
        assert result.time != 0
        assert result.iterations <= self.max_iterations
        assert isinstance(result.stopping_criterion, str)

    def test_optimization_log(self):
        optimizer = pymanopt.optimizers.ConjugateGradient(
            max_iterations=self.max_iterations, verbosity=0
        )
        result = optimizer.run(self.problem)
        assert (
            result.log["stopping_criteria"]["max_iterations"]
            == self.max_iterations
        )
        assert result.log["iterations"] is None

        optimizer = pymanopt.optimizers.ConjugateGradient(
            max_iterations=self.max_iterations, verbosity=0, log_verbosity=1
        )
        result = optimizer.run(self.problem)
        iterations = result.log["iterations"]
        assert iterations is not None
        assert len(iterations["cost"]) == result.iterations

==> pymanopt-2.2.1.tar.gz: pymanopt-2.2.1/tests/optimizers/test_optimizers.py <==
import autograd.numpy as np
import pytest

import pymanopt
import pymanopt.optimizers
from pymanopt.manifolds import Sphere


class TestOptimizers:
    @pytest.fixture(autouse=True)
    def setup(self):
        n = 32
        matrix = np.random.normal(size=(n, n))
        self.manifold = manifold = Sphere(n)
        self.max_iterations = 50

        @pymanopt.function.autograd(manifold)
        def cost(point):
            return -point.T @ matrix @ point

        self.problem = pymanopt.Problem(manifold, cost)

    @pytest.mark.parametrize("optimizer_name", pymanopt.optimizers.OPTIMIZERS)
    def test_optimizers(self, optimizer_name):
        optimizer = getattr(pymanopt.optimizers, optimizer_name)(
            max_iterations=self.max_iterations, verbosity=0
        )
        result = optimizer.run(self.problem)
        assert result.point.shape == self.manifold.random_point().shape
        assert result.time != 0
        assert result.iterations <= self.max_iterations
        assert isinstance(result.stopping_criterion, str)

    def test_optimization_log(self):
        optimizer = pymanopt.optimizers.ConjugateGradient(
            max_iterations=self.max_iterations, verbosity=0
        )
        result = optimizer.run(self.problem)
        assert (
            result.log["stopping_criteria"]["max_iterations"]
            == self.max_iterations
        )
        assert result.log["iterations"] is None

        optimizer = pymanopt.optimizers.ConjugateGradient(
            max_iterations=self.max_iterations, verbosity=0, log_verbosity=1
        )
        result = optimizer.run(self.problem)
        iterations = result.log["iterations"]
        assert iterations is not None
        assert len(iterations["cost"]) == result.iterations
